import dynamic from "next/dynamic";
import React from "react";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";

interface RouteConfig {
  name: string;
  path: string;
}

// Components mapping
const componentMap: Record<string, any> = {
  Dashboard: dynamic(() => import("../dashboard")),
  Profile: dynamic(() => import("../profile")),
};

export function useDynamicRoutes(routesConfig: RouteConfig[]) {
  const router = useRouter();
  const [currentRoute, setCurrentRoute] = useState<string | null>(null);

  useEffect(() => {
    const handleDynamicRoutes = (routeName: string) => {
      const matchingRoute = routesConfig.find(
        (route) => route.name === routeName,
      );

      if (matchingRoute) {
        setCurrentRoute(matchingRoute.name);
        router.push(matchingRoute.path);
      } else {
        console.warn(`Route ${routeName} not found`);
      }
    };

    // Expose to window for external control
    (window as any).handleDynamicRoutes = handleDynamicRoutes;
  }, [router, routesConfig]);

  return currentRoute ? componentMap[currentRoute] : null;
}

// Component to dynamically render routes
export function DynamicRouteRenderer({ routeName }: { routeName: string }) {
  const Component = componentMap[routeName] || (() => <p>Route Not Found</p>);
  return <Component />;
}

export default { useDynamicRoutes, DynamicRouteRenderer };
